@@ -15,6 +15,7 @@
 from __future__ import division
 
 import sys
+from math import ceil
 
 # Third party imports
 from qtpy.QtCore import (QEasingCurve, QPoint, QPropertyAnimation, QRectF, Qt,
@@ -28,8 +29,17 @@ from qtpy.QtWidgets import (QAction, QApplication, QComboBox, QDialog,
 
 # Local imports
 from spyder.config.base import _, get_image_path
+from spyder.config.gui import is_dark_interface
 from spyder.py3compat import to_binary_string
 from spyder.utils.qthelpers import add_actions, create_action
+from spyder.utils import icon_manager as ima
+
+
+if is_dark_interface():
+    MAIN_TOP_COLOR = MAIN_BG_COLOR = QColor.fromRgb(25, 35, 45)
+else:
+    MAIN_TOP_COLOR = QColor.fromRgb(230, 230, 230)
+    MAIN_BG_COLOR = QColor.fromRgb(255, 255, 255)
 
 # FIXME: Known issues
 # How to handle if an specific dockwidget does not exists/load, like ipython
@@ -38,7 +48,6 @@ from spyder.utils.qthelpers import add_actions, create_action
 class SpyderWidgets(object):
     """List of supported widgets to highlight/decorate"""
     # Panes
-    external_console = 'extconsole'
     ipython_console = 'ipyconsole'
     editor = 'editor'
     editor_line_number_area = 'editor.get_current_editor().linenumberarea'
@@ -74,7 +83,7 @@ def get_tours(index=None):
 def get_tour(index):
     """
     This function generates a list of tours.
-    
+
     The index argument is used to retrieve a particular tour. If None is
     passed, it will return the full list of tours. If instead -1 is given,
     this function will return a test tour
@@ -84,7 +93,7 @@ def get_tour(index):
     updated accordingly
     """
     sw = SpyderWidgets
-    qtconsole_link = "http://ipython.org/ipython-doc/stable/interactive/qtconsole.html"
+    qtconsole_link = "https://qtconsole.readthedocs.io/en/stable/index.html"
 
     # This test should serve as example of keys to use in the tour frame dics
     test = [{'title': "Welcome to Spyder introduction tour",
@@ -163,7 +172,7 @@ def get_tour(index):
               'widgets': [sw.ipython_console],
               'run': ["li = list(range(100))", "d = {'a': 1, 'b': 2}"]
               },
-              
+
              {'title': _("The Variable Explorer"),
               'content': _("In this pane you can view and edit the variables "
                            "generated during the execution of a program, or "
@@ -177,21 +186,6 @@ def get_tour(index):
               'widgets': [sw.variable_explorer],
               'interact': True},
 
-             {'title': _("The Python console"),
-              'content': _("You can also run your code on a Python console. "
-                           "These consoles are useful because they let you "
-                           "run a file in a console dedicated only to it."
-                           "To select this behavior, please press the <b>F6</b> "
-                           "key.<br><br>"
-                           "By pressing the button below and then focusing the "
-                           "Variable Explorer, you will notice that "
-                           "Python consoles are also connected to that pane, "
-                           "and that the Variable Explorer only shows "
-                           "the variables of the currently focused console."),
-              'widgets': [sw.external_console],
-              'run': ["a = 2", "s='Hello, world!'"],
-              },
-
              {'title': _("Help"),
               'content': _("This pane displays documentation of the "
                            "functions, classes, methods or modules you are "
@@ -456,9 +450,9 @@ class FadingCanvas(FadingDialog):
                     width, height = geo.width(), geo.height()
                     point = widget.mapTo(self.parent, QPoint(0, 0))
                     x, y = point.x(), point.y()
-    
+
                     temp_path.addRect(QRectF(x, y, width, height))
-    
+
                     temp_region = QRegion(x, y, width, height)
 
                 if self.interaction_on:
@@ -542,7 +536,8 @@ class FadingCanvas(FadingDialog):
 
 class FadingTipBox(FadingDialog):
     """ """
-    def __init__(self, parent, opacity, duration, easing_curve, tour=None):
+    def __init__(self, parent, opacity, duration, easing_curve, tour=None,
+                 color_top=None, color_back=None, combobox_background=None):
         super(FadingTipBox, self).__init__(parent, opacity, duration,
                                            easing_curve)
         self.holder = self.anim  # needed for qt to work
@@ -550,8 +545,6 @@ class FadingTipBox(FadingDialog):
         self.tour = tour
 
         self.frames = None
-        self.color_top = QColor.fromRgb(230, 230, 230)
-        self.color_back = QColor.fromRgb(255, 255, 255)
         self.offset_shadow = 0
         self.fixed_width = 300
 
@@ -563,11 +556,17 @@ class FadingTipBox(FadingDialog):
         self.setModal(False)
 
         # Widgets
-        self.button_home = QPushButton("<<")
-        self.button_close = QPushButton("X")
-        self.button_previous = QPushButton(" < ")
-        self.button_end = QPushButton(">>")
-        self.button_next = QPushButton(" > ")
+        def toolbutton(icon):
+            bt = QToolButton()
+            bt.setAutoRaise(True)
+            bt.setIcon(icon)
+            return bt
+
+        self.button_close = toolbutton(ima.icon("tour.close"))
+        self.button_home = toolbutton(ima.icon("tour.home"))
+        self.button_previous = toolbutton(ima.icon("tour.previous"))
+        self.button_end = toolbutton(ima.icon("tour.end"))
+        self.button_next = toolbutton(ima.icon("tour.next"))
         self.button_run = QPushButton(_('Run code'))
         self.button_disable = None
         self.button_current = QToolButton()
@@ -593,46 +592,29 @@ class FadingTipBox(FadingDialog):
 
         arrow = get_image_path('hide.png')
 
-        self.stylesheet = '''QPushButton {
-                             background-color: rgbs(200,200,200,100%);
-                             color: rgbs(0,0,0,100%);
-                             border-style: outset;
-                             border-width: 1px;
-                             border-radius: 3px;
-                             border-color: rgbs(100,100,100,100%);
-                             padding: 2px;
-                             }
-
-                             QPushButton:hover {
-                             background-color: rgbs(150, 150, 150, 100%);
-                             }
-
-                             QPushButton:disabled {
-                             background-color: rgbs(230,230,230,100%);
-                             color: rgbs(200,200,200,100%);
-                             border-color: rgbs(200,200,200,100%);
-                             }
-
-                             QComboBox {
+        self.color_top = color_top
+        self.color_back = color_back
+        self.combobox_background = combobox_background
+        self.stylesheet = '''QComboBox {{
                              padding-left: 5px;
-                             background-color: rgbs(230,230,230,100%);
+                             background-color: {}
                              border-width: 0px;
                              border-radius: 0px;
                              min-height:20px;
                              max-height:20px;
-                             }
+                             }}
 
-                             QComboBox::drop-down  {
+                             QComboBox::drop-down  {{
                              subcontrol-origin: padding;
                              subcontrol-position: top left;
                              border-width: 0px;
-                             }
-                             
-                             QComboBox::down-arrow {
-                             image: url(''' + arrow + ''');
-                             }
-                             
-                             '''
+                             }}
+
+                             QComboBox::down-arrow {{
+                             image: url({});
+                             }}
+
+                             '''.format(self.combobox_background.name(), arrow)
         # Windows fix, slashes should be always in unix-style
         self.stylesheet = self.stylesheet.replace('\\', '/')
 
@@ -751,14 +733,14 @@ class FadingTipBox(FadingDialog):
 
     def set_pos(self, x, y):
         """ """
-        self.x = x
-        self.y = y
-        self.move(QPoint(x, y))
+        self.x = ceil(x)
+        self.y = ceil(y)
+        self.move(QPoint(self.x, self.y))
 
     def build_paths(self):
         """ """
         geo = self.geometry()
-        radius = 30
+        radius = 0
         shadow = self.offset_shadow
         x0, y0 = geo.x(), geo.y()
         width, height = geo.width() - shadow, geo.height() - shadow
@@ -867,8 +849,8 @@ class AnimatedTour(QWidget):
         QWidget.__init__(self, parent)
 
         self.parent = parent
-        
-        # Variables to adjust 
+
+        # Variables to adjust
         self.duration_canvas = [666, 666]
         self.duration_tips = [333, 333]
         self.opacity_canvas = [0.0, 0.7]
@@ -898,10 +880,12 @@ class AnimatedTour(QWidget):
                                    self.color, tour=self)
         self.tips = FadingTipBox(self.parent, self.opacity_tips,
                                  self.duration_tips, self.easing_curve,
-                                 tour=self)
+                                 tour=self, color_top=MAIN_TOP_COLOR,
+                                 color_back=MAIN_BG_COLOR,
+                                 combobox_background=MAIN_TOP_COLOR)
 
         # Widgets setup
-        # Needed to fix issue #2204
+        # Needed to fix spyder-ide/spyder#2204.
         self.setAttribute(Qt.WA_TransparentForMouseEvents)
 
         # Signals and slots
@@ -928,20 +912,22 @@ class AnimatedTour(QWidget):
 
     def _resized(self, event):
         """ """
-        size = event.size()
-        self.canvas.setFixedSize(size)
-        self.canvas.update_canvas()
+        if self.is_running:
+            size = event.size()
+            self.canvas.setFixedSize(size)
+            self.canvas.update_canvas()
 
-        if self.is_tour_set:
-            self._set_data()
+            if self.is_tour_set:
+                self._set_data()
 
     def _moved(self, event):
         """ """
-        pos = event.pos()
-        self.canvas.move(QPoint(pos.x(), pos.y()))
+        if self.is_running:
+            pos = event.pos()
+            self.canvas.move(QPoint(pos.x(), pos.y()))
 
-        if self.is_tour_set:
-            self._set_data()
+            if self.is_tour_set:
+                self._set_data()
 
     def _close_canvas(self):
         """ """
@@ -1095,13 +1081,13 @@ class AnimatedTour(QWidget):
             if dockwidgets[0] is not None:
                 geo = dockwidgets[0].geometry()
                 x, y, width, height = geo.x(), geo.y(), geo.width(), geo.height()
-    
+
                 point = dockwidgets[0].mapToGlobal(QPoint(0, 0))
                 x_glob, y_glob = point.x(), point.y()
-    
+
                 # Check if is too tall and put to the side
                 y_fac = (height / self.height_main) * 100
-    
+
                 if y_fac > 60:  # FIXME:
                     if x < self.tips.width():
                         x = x_glob + width + delta
@@ -1186,7 +1172,7 @@ class AnimatedTour(QWidget):
 #        self.parent_h = height
 
         # FIXME: reset step to last used value
-        # Reset step to begining
+        # Reset step to beginning
         self.step_current = self.last_frame_active
 
         # Adjust the canvas size to match the main window size
@@ -1200,10 +1186,12 @@ class AnimatedTour(QWidget):
     def close_tour(self):
         """ """
         self.tips.fade_out(self._close_canvas)
-        self.tips.show()
+        self.canvas.set_interaction(False)
+        self._set_modal(True, [self.tips])
+        self.canvas.hide()
 
         try:
-            # set the last played frame by updating the available tours in 
+            # set the last played frame by updating the available tours in
             # parent. This info will be lost on restart.
             self.parent.tours_available[self.active_tour_index]['last'] =\
                 self.step_current
@@ -1257,13 +1245,13 @@ class AnimatedTour(QWidget):
 
     def gain_focus(self):
         """Confirm if the tour regains focus and unhides the tips."""
-        if (self.is_running and self.any_has_focus() and 
+        if (self.is_running and self.any_has_focus() and
             not self.setting_data and self.hidden):
             self.unhide_tips()
 
     def any_has_focus(self):
         """Returns if tour or any of its components has focus."""
-        f = (self.hasFocus() or self.parent.hasFocus() or 
+        f = (self.hasFocus() or self.parent.hasFocus() or
              self.tips.hasFocus() or self.canvas.hasFocus())
         return f
 
